@@ -3,7 +3,7 @@
     S3 classes for dealing with nodes and splits
     *\file S3Classes.c
     *\author $Author: hothorn $
-    *\date $Date: 2006-09-15 13:27:26 +0200 (Fri, 15 Sep 2006) $
+    *\date $Date: 2007-07-23 09:44:00 +0200 (Mon, 23 Jul 2007) $
 */
                 
 #include "party.h"
@@ -21,6 +21,7 @@ void C_init_node(SEXP node, int nobs, int ninputs, int nsurr, int q) {
         SET_VECTOR_ELT(node, S3_WEIGHTS, weights = allocVector(REALSXP, nobs));
     else
         SET_VECTOR_ELT(node, S3_WEIGHTS, R_NilValue);
+    SET_VECTOR_ELT(node, S3_SUMWEIGHTS, allocVector(REALSXP, 1));
     SET_VECTOR_ELT(node, S3_CRITERION, 
         criterion = allocVector(VECSXP, CRITERION_LENGTH));
     /* teststats */
@@ -56,6 +57,10 @@ SEXP S3get_nodeweights(SEXP node) {
     return(VECTOR_ELT(node, S3_WEIGHTS));
 }
 
+double S3get_sumweights(SEXP node) {
+    REAL(VECTOR_ELT(node, S3_SUMWEIGHTS))[0];
+}
+
 SEXP S3get_teststat(SEXP node) {
     return(VECTOR_ELT(VECTOR_ELT(node, S3_CRITERION), S3_STATISTICS));
 }
